@@ -63,7 +63,9 @@ class Socket(object):
 
     def handle_get_request(self, environ, start_response):
         """Handle a long-polling GET request from the client."""
-        connections = environ.get('HTTP_CONNECTION', '').lower().split(',')
+        connections = [
+            s.strip()
+            for s in environ.get('HTTP_CONNECTION', '').lower().split(',')]
         transport = environ.get('HTTP_UPGRADE', '').lower()
         if 'upgrade' in connections and transport in self.upgrade_protocols:
             self.server.logger.info('%s: Received request to upgrade to %s',
@@ -101,8 +103,9 @@ class Socket(object):
         """Upgrade the connection from polling to websocket."""
         if self.upgraded:
             raise IOError('Socket has been upgraded already')
-        ws = self.server.async['websocket'].WebSocketWSGI(
-            self._websocket_handler)
+        websocket_class = getattr(self.server.async['websocket'],
+                                  self.server.async['websocket_class'])
+        ws = websocket_class(self._websocket_handler)
         return ws(environ, start_response)
 
     def _websocket_handler(self, ws):
@@ -139,7 +142,8 @@ class Socket(object):
                 except:
                     break
 
-        writer_task = self.server.async['threading'].Thread(target=writer)
+        writer_task = getattr(self.server.async['threading'],
+                              self.server.async['thread_class'])(target=writer)
         writer_task.start()
 
         self.server.logger.info(
